<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\SubCategory;

class CategoryController extends Controller
{
    public function category(){
        $categories = Category::all();
        return view('categories', compact('categories'));
    }

    public function storeCategory(Request $request)
    {
        $request->validate([
            'category_name' => 'required|string',
            'category_image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        $imagePath = $request->file('category_image')->store('category_images', 'public');


        $category = new Category();
        $category->category_name = $request->category_name;
        $category->category_image = $imagePath;
        $category->save();

        return redirect()->back()->with('success', 'Category created successfully.');
    }

    public function destroy($id)
    {
        $category = Category::findOrFail($id);
        $category->delete();
        return redirect()->route('categories')->with('success', 'Category deleted successfully');
    }


    //Sub Categories 
    public function subcategory(){
        $categories = Category::all();
        $subcategories = SubCategory::all();
        return view('subcategories', compact('categories' , 'subcategories' ));
    }

    public function storeSubcategory(Request $request)
    {
        $request->validate([
            'parent_category_id' => 'required|exists:categories,id',
            'subcategory_name' => 'required|string',
            'subcategory_image' => 'required|image|max:2048',
        ]);

        $imagePath = $request->file('subcategory_image')->store('subcategory_images', 'public');

        $subcategory = new SubCategory();
        $subcategory->category_id = $request->input('parent_category_id');
        $subcategory->subcategory_name = $request->input('subcategory_name');
        $subcategory->subcategory_image = $imagePath;

        $subcategory->save();

        return redirect()->back()->with('success', 'SUB Category created successfully.');
    }

    public function deletesubCategory($id){
        $subcategory = SubCategory::findOrFail($id);
        $subcategory->delete();
        return redirect()->route('subcategory')->with('success', 'Sub Category deleted successfully');
    }

}
